/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef UNITSELECTOR_H
#define UNITSELECTOR_H

#include <QtGui/QDialog>

class QString;
class ButtonSelector;

class UnitSelector : public QDialog
{
    Q_OBJECT

public:
    UnitSelector(QWidget* parent = 0);

signals:
    void unitChanged();
    void orientationChanged();

private slots:
    void saveUnit();

private:
    ButtonSelector* selector_;
    QString unit_;
    ButtonSelector* orientationSelector_;
    QString orientation_;
};

#endif
